#ifndef ONTOLOGY_LEXER_HH
#define ONTOLOGY_LEXER_HH

#include <string>

#include <boost/regex.hpp>

using namespace std;

// ---------- Request parsing for ONTO-REQ  ----------
static const string K_NULL	= "null";
static const string K_ONTOREQ	= QUOTE + "ONTO-REQ" + QUOTE;
static const string K_AGENT	= QUOTE + "AGENT" + QUOTE;
static const string K_OBJECT	= QUOTE + "OBJECT" + QUOTE;
static const string K_PROPERTY	= QUOTE + "PROPERTY" + QUOTE;

static const string AGENT	= K_AGENT + JSEP + STRING;
static const string AGNULL	= K_AGENT + JSEP + K_NULL;
static const string OBJECT	= K_OBJECT + JSEP + STRING;
static const string PROPERTY	= K_PROPERTY + JSEP + STRING;

static const string ONTOFIND	= LSCOPE + K_ONTOREQ + JSEP + LSCOPE + AGNULL + COMMA + OBJECT + COMMA + PROPERTY + RSCOPE + RSCOPE;
static const string ONTOFFA	= LSCOPE + K_ONTOREQ + JSEP + LSCOPE + AGENT + COMMA + OBJECT + COMMA + PROPERTY + RSCOPE + RSCOPE;

// ---------- REGULAR EXPRESSION  ----------
static const boost::regex FindRequest(ONTOFIND);
static const boost::regex FindForAgentRequest(ONTOFFA);


// ---------- Request parsing for ONTO-REQ-ALL ----------
static const string K_ONTOREQALL	= QUOTE + "ONTO-REQ-ALL" + QUOTE;
static const string K_OBJECTS		= QUOTE + "OBJECTS" + QUOTE;
static const string K_PROPERTIES	= QUOTE + "PROPERTIES" + QUOTE;
static const string K_NAME		= QUOTE + "NAME" + QUOTE;

static const string OBJECTS		= K_OBJECTS + JSEP + LBRAC + "(.*)" + RBRAC;

static const string ONTOFINDALL		= LSCOPE + K_ONTOREQALL + JSEP + LSCOPE + AGNULL + COMMA + OBJECTS + RSCOPE + RSCOPE;
static const string ONTOFINDAGENTALL	= LSCOPE + K_ONTOREQALL + JSEP + LSCOPE + AGENT + COMMA + OBJECTS + RSCOPE + RSCOPE;

static const string COMPLETE_OBJECT	= LSCOPE + K_NAME + JSEP + STRING + COMMA + K_PROPERTIES + JSEP + LBRAC + "(.*?)" + RBRAC + RSCOPE;

// ---------- REGULAR EXPRESSION  ----------
static const boost::regex FindAllRequest(ONTOFINDALL);
static const boost::regex FindAllForAgentRequest(ONTOFINDAGENTALL);

static const boost::regex ObjectRegex(COMPLETE_OBJECT);
static const boost::regex PropertyRegex(WORD);

#endif //ONTOLOGY_LEXER_HH
